==> protein_turnover_website-0.3.12-py3-none-any.whl: protein_turnover_website/config.py <==
from __future__ import annotations

APP_NAME = "Protein Turnover"

# only used with email logger
# ADMINS = ['your.email@gmail.com']
MAIL_SUBJECT = "turnover pipeline website"
# where to send email to...
MAIL_SERVER = "antivirus.uwa.edu.au"


# used for input placeholder
MAIL_PLACEHOLDER = "your.name@uwa.edu.au"

KILL_OK = True

# https://matplotlib.org/stable/api/matplotlib_configuration_api.html#matplotlib
# non-interactive backends: agg, cairo, pdf, pgf, ps, svg, template
MATPLOTLIB_BACKEND = "agg"
# use css fonts for fontawesome
FONT_ICONS = True
# start length for datatables.net
PROTEIN_PAGE_LENGTH = 50


# These are the top directory locations available to users
# of this website. All files below these points will be visible.

# Tuple of "absolute path of directory", "nickname" , "file restriction regex [optional]"

# most restrictive/longest path first! e.g.
# restrict = r"^.*\.(mzML|pep.xml)$"
# MOUNTPOINTS = [
#     ("/path/to/protein_turnover_data", "Turnover", restrict),
#     ("/path/to/home", "HOME"),
# ]
MOUNTPOINTS = [("~", "HOME")]
# Don't allow soft links in MountPoint directory trees...
ALLOW_LINKS = False

# where jobsfile live [required]
# JOBSDIR = "/path/to/jobs-directory"
JOBSDIR = "~/turnover_jobs"

# where cache files live [required]
# CACHEDIR = "/path/to/cachedir"
CACHEDIR = "~/turnover_cache"

dpi = 96
FIGSIZE = (642.0 / dpi, 3 * 400.0 / dpi)
LANDSCAPE = (3 * 642.0 / dpi, 400.0 / dpi)

# wait 60 secs for download to complete (checking every second)
COOKIE_MAX_ATTEMPTS = 60

# set this to true for nginx
USE_X_SENDFILE = False
# last 1000 bytes of logfile
LOG_READ = 1000
# for HTML meta tags like "canonical"
SITE_URL = "https://turnover.plantenergy.edu.au"
# delay (ms) before we switch from job create page to
# job index page after submitting a new job
REFRESH_DELAY = 1000

# set this to ensure a password is required
# can be a simple password string or a dictionary of {email: password}
SITE_PASSWORD: str | dict[str, str] | None = None

# if SITE_PASSWORD is set these are the endpoints that are still public...
PUBLIC_ENDPOINTS = [
    "view.index",
    "inspect.about",
    "view.configuration",
]

# add iso_peaks_nr_<n> columns if necessary....
FIXSQLITE = True

# we a running a single user website (via turnover web)
WEBSITE_STATE = "multi_user"

==> protein_turnover_website-0.4.0-py3-none-any.whl: protein_turnover_website/config.py <==
from __future__ import annotations

APP_NAME = "Protein Turnover"

# only used with email logger
ADMINS: list[str] = []  # ['your.email@gmail.com']
MAIL_SUBJECT = "turnover pipeline website"
# where should logger send email to...
MAIL_SERVER = "mailhost"


# used for input placeholder
MAIL_PLACEHOLDER = "your.name@uwa.edu.au"

KILL_OK = True

# https://matplotlib.org/stable/api/matplotlib_configuration_api.html#matplotlib
# non-interactive backends: agg, cairo, pdf, pgf, ps, svg, template
MATPLOTLIB_BACKEND = "agg"
# use css fonts for fontawesome
FONT_ICONS = True
# start length for datatables.net
PROTEIN_PAGE_LENGTH = 50


# These are the top directory locations available to users
# of this website. All files below these points will be visible.

# Tuple of "absolute path of directory", "nickname" , "file restriction regex [optional]"

# most restrictive/longest path first! e.g.
# restrict = r"^.*\.(mzML|pep.xml)$"
# MOUNTPOINTS = [
#     ("/path/to/protein_turnover_data", "Turnover", restrict),
#     ("/path/to/home", "HOME"),
# ]
MOUNTPOINTS = [("~", "HOME")]
# Don't allow soft links in MountPoint directory trees...
ALLOW_LINKS = False

# where jobsfile live [required]
# JOBSDIR = "/path/to/jobs-directory"
JOBSDIR = "~/turnover_jobs"

# where cache files live [required]
# CACHEDIR = "/path/to/cachedir"
CACHEDIR = "~/turnover_cache"

dpi = 96
FIGSIZE = (642.0 / dpi, 3 * 400.0 / dpi)
LANDSCAPE = (3 * 642.0 / dpi, 400.0 / dpi)

# wait 60 secs for download to complete (checking every second)
COOKIE_MAX_ATTEMPTS = 60

# set this to true for nginx
USE_X_SENDFILE = False
# last 1000 bytes of logfile
LOG_READ = 1000
# for HTML meta tags like "canonical"
SITE_URL = "https://turnover.plantenergy.edu.au"
# delay (ms) before we switch from job create page to
# job index page after submitting a new job
REFRESH_DELAY = 1000

# set this to ensure a password is required
# can be a simple password string or a dictionary of {email: password}
SITE_PASSWORD: str | dict[str, str] | None = None

# if SITE_PASSWORD is set these are the endpoints that are still public...
PUBLIC_ENDPOINTS = [
    "view.index",
    "inspect.about",
    "view.configuration",
]

# add iso_peaks_nr_<n> columns if necessary....
FIXSQLITE = True

# we a running a single user website (via turnover web)
WEBSITE_STATE = "multi_user"
